from streamtask.version import __version__
from streamtask.streamtask import *